@@ -151,6 +151,7 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
 
     variation_class = "variation-dashboard"
     _portlet_names = ["portlet-my-ras", "portlet-available-tools"]
+    form_action_name = "dashboard-switcher"
 
     @property
     @memoize
@@ -363,6 +364,11 @@ class Assessments(BrowserView):
     def webhelpers(self):
         return api.content.get_view("webhelpers", self.context, self.request)
 
+    @property
+    @memoize
+    def form_action_name(self):
+        return self.__name__
+
     @property
     @memoize
     def sessions(self):
@@ -382,6 +388,11 @@ class Surveys(BrowserView, SurveyTemplatesMixin):
     def webhelpers(self):
         return api.content.get_view("webhelpers", self.context, self.request)
 
+    @property
+    @memoize
+    def form_action_name(self):
+        return self.__name__
+
     def get_filters(self):
         filters = {}
         get = self.request.form.get
@@ -472,6 +483,12 @@ class Surveys(BrowserView, SurveyTemplatesMixin):
             key=lambda lang: lang["code"],
         )
 
+    def __call__(self):
+        utils.setLanguage(
+            self.request, self.context, getattr(self.context, "language", None)
+        )
+        return super(Surveys, self).__call__()
+
 
 class PortletBase(BrowserView):
     @property
