@@ -398,6 +398,10 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
     def current_profile(self):
         return extractProfile(self.context.aq_parent, self.session)
 
+    @property
+    def has_location_questions(self):
+        return any([x["use_location_question"] for x in self.profile_questions])
+
     def update(self):
         utils.setLanguage(self.request, self.survey, self.survey.language)
         if not self.profile_questions or self.request.method == "POST":
@@ -462,7 +466,7 @@ class ContentsPreview(BrowserView):
 
     @property
     def title_custom_risks(self):
-        return api.portal.translate(_("Custom risks", default=u"Custom risks"))
+        return api.portal.translate(_("label_custom_risks", default=u"Custom risks"))
 
     def get_session_nodes(self):
         """Return an ordered list of all tree items for the current survey.
