@@ -35,9 +35,11 @@ from plone.i18n.normalizer import idnormalizer
 from plone.memoize import forever
 from plone.memoize.instance import memoize
 from plone.memoize.view import memoize_contextless
+from plone.registry.interfaces import IRegistry
 from plonetheme.nuplone.utils import isAnonymous
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.Five import BrowserView
 from Products.statusmessages.interfaces import IStatusMessage
 from six.moves.urllib.parse import urlencode
@@ -147,6 +149,13 @@ class WebHelpers(BrowserView):
             "euphorie.allow_guest_accounts", default=False
         )
 
+    @property
+    @memoize
+    def allow_self_registration(self):
+        registry = getUtility(IRegistry)
+        security_settings = registry.forInterface(ISecuritySchema, prefix="plone")
+        return security_settings.enable_self_reg
+
     @property
     @memoize
     def use_involve_phase(self):
@@ -387,11 +396,13 @@ class WebHelpers(BrowserView):
         return lang
 
     @memoize_contextless
-    def getNameForLanguageCode(self, langCode):
+    def getNameForLanguageCode(self, langCode, native=True):
         lang_util = getUtility(ILanguageUtility)
         info = lang_util.getAvailableLanguageInformation().get(langCode, None)
         if info is not None:
-            return info.get("native", info.get("name", None))
+            if native:
+                return info.get("native", info.get("name", None))
+            return info.get("name", None)
         return None
 
     @memoize
@@ -786,8 +797,11 @@ class WebHelpers(BrowserView):
     def timezoned_date(self, mydate=None):
         if mydate is None:
             return None
-        utc = tz.gettz(self.server_timezone)
-        return mydate.replace(tzinfo=utc)
+        # If the date already has a timezone, don't touch it
+        if mydate.tzinfo is not None:
+            return mydate
+        local_tz = tz.gettz(self.server_timezone)
+        return mydate.replace(tzinfo=local_tz)
 
     @property
     @memoize
