@@ -254,7 +254,7 @@ class SurveyTreeItem(BaseObject):
 
         item.session = self.session
         item.depth = self.depth + 1
-        item.path = (self.path and self.path or "") + "%03d" % index
+        item.path = (self.path or "") + "%03d" % index
         item.parent_id = self.id
         if self.profile_index != -1:
             item.profile_index = self.profile_index
@@ -307,7 +307,12 @@ class Group(BaseObject):
     responsible_fullname = schema.Column(
         types.Unicode(32),
     )
-    active = schema.Column(types.Boolean(), default=True)
+
+    deactivated = schema.Column(
+        types.DateTime,
+        nullable=True,
+        default=None,
+    )
 
     children = relationship(
         "Group",
@@ -339,7 +344,7 @@ class Group(BaseObject):
         in the tree widget
         """
         title = u"{obs}{name}".format(
-            obs="[obs.] " if not self.active else "",
+            obs="[obs.] " if not self.deactivated else "",
             name=self.short_name or self.group_id,
         )
         if self.responsible_fullname:
@@ -455,6 +460,12 @@ class Account(BaseObject):
         default=functions.now(),
     )
 
+    last_login = schema.Column(
+        types.DateTime,
+        nullable=True,
+        default=None,
+    )
+
     @property
     def groups(self):
         group = self.group
