@@ -37,7 +37,7 @@ TAG = re.compile(u"<.*?>")
 UNWANTED = re.compile(u"(\r|&#13;|\xad)")
 WHITE = re.compile(" +")
 
-REGION_NAMES = {"eu": _(u"European Union")}
+REGION_NAMES = {"eu": _(u"European Union"), "EU": _(u"European Union")}
 
 CUSTOM_COUNTRY_NAMES = {
     # This are areas whose country codes have not stabilized enough
@@ -112,8 +112,8 @@ TOOL_TYPES = OrderedDict(
                 ),
                 "intro_extra_always_present": _(
                     "select_add_existing_measure",
-                    default=u"Select or add any measures that are <strong>already in "
-                    u"place</strong>.",
+                    default=u"Select or add any measures that are <strong>already "
+                    u"implemented</strong>.",
                 ),
                 "button_add_extra": _(
                     "button_add_existing_measure",
