@@ -8,7 +8,6 @@ from euphorie.client.model import ActionPlan
 from euphorie.client.model import Session
 from euphorie.client.model import SurveySession
 from euphorie.client.model import SurveyTreeItem
-from euphorie.content.api.entry import access_api
 from euphorie.content.countrymanager import ICountryManager
 from euphorie.content.risk import EnsureInterface
 from euphorie.content.risk import IRisk
@@ -58,8 +57,6 @@ class SitePublishTraverser(DefaultPublishTraverse):
     """
 
     def publishTraverse(self, request, name):
-        if name == "api":
-            return access_api(request).__of__(self.context)
         return super(SitePublishTraverser, self).publishTraverse(request, name)
 
 
@@ -85,6 +82,12 @@ class EuphorieRefreshResourcesTimestamp(BrowserView):
         return "OK"
 
 
+class GetEuphorieResourcesTimestamp(EuphorieRefreshResourcesTimestamp):
+    def __call__(self):
+        """Get the resource timestamp"""
+        return self.resources_timestamp
+
+
 class ManageEnsureInterface(BrowserView):
     def set_evaluation_method_interfaces(self):
         def walk(node):
